<img src="docs/_static/logo.png" width="400"/>

Phylogenetic inference for sequence data with repeated genotypes.

[![build and test](https://github.com/matsengrp/gctree/actions/workflows/build-and-test.yml/badge.svg)](https://github.com/matsengrp/gctree/actions/workflows/build-and-test.yml)
[![Docs build and deploy](https://github.com/matsengrp/gctree/actions/workflows/docs-build-and-deploy.yml/badge.svg)](https://github.com/matsengrp/gctree/actions/workflows/docs-build-and-deploy.yml)
[![PyPI version](https://badge.fury.io/py/gctree.svg)](https://badge.fury.io/py/gctree)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/gctree.svg)](https://anaconda.org/conda-forge/gctree)

#### See [documentation](https://matsengrp.github.io/gctree) for install and usage information.


